%   Fresnel coefficient test bench
clear all;
%close all;

% Silicon at 633nm
lambda633 = 633e-9;
nR633 = 3.8736;
nI633 = 0.0157;

% Silicon at 850nm
lambda850 = 850e-9;
nR850 = 3.65;
nI850 = 0.004;

%==== INPUT RAY ====
E0 = 1;
dtheta = 0.1;
theta_min = 0;
theta_max = 89.99;
THETA_I_DEG = theta_min:dtheta:theta_max; % [deg]
THETA_I = THETA_I_DEG * pi/180; % [rad]

lambda = lambda850; % [m]

%==== FABRY-PEROT EXAMPLE ====
n0 = 1;
n1 = nR850;
n2 = 1;
nd = 4;
d = nd*lambda;

%==== ANTI REFLECTION LAYER ====
% n0 = 1;
% n1 = 1.9105; % [-]
% %n1 = 1.9935; % [-]
% n2 = nR850;
% theta_deg = 0;
% theta_rad = theta_deg/180*pi;
% nd = 0.25*cos(theta_rad)/n1;
% d = nd*lambda % [m]

%==== FRESNEL COEFFICIENTS ====
[TS01,TP01,RS01,RP01,THETA_T_01] = fresnel(n0,n1,THETA_I);
[TS10,TP10,RS10,RP10,THETA_T_10] = fresnel(n1,n0,THETA_T_01);
[TS12,TP12,RS12,RP12,THETA_T_12] = fresnel(n1,n2,THETA_T_01);

%==== PHASE SHIFT ====
k0 = 2*pi/lambda;
PHI = n1*k0*2*d./cos(THETA_T_01);

%==== RESONANCES ====
TSR = TS01.*TS12.*exp(1i*PHI).*( 1 ./ ( 1-(RS10.*RS12.*exp(1i*PHI)) ) );
TPR = TP01.*TP12.*exp(1i*PHI).*( 1 ./ ( 1-(RP10.*RP12.*exp(1i*PHI)) ) );

RSR = RS01 + TS01.*RS12.*TS10.*exp(1i*PHI).*( 1 ./ ( 1-(RS12.*RS10.* exp( 1i*PHI ) ) ) ); 
RPR = RP01 + TP01.*RP12.*TP10.*exp(1i*PHI).*( 1 ./ ( 1-(RP12.*RP10.* exp( 1i*PHI ) ) ) );

%==== TRANSMITTED AND REFLECTED AMPLITUDE FROM RESONANCES ====
EST = E0*TSR;
EPT = E0*TSR;

ESR = E0*RSR;
EPR = E0*RPR;

%==== PLOT AMPLITUDES ====

ylabel100 = 'E [V/m]';
      
figure(100);hold off;
subplot(211);plot(THETA_I_DEG,real(EST),THETA_I_DEG,real(ESR));legend('E_t/E_0','E_r/E_0','location','northwest');title(sprintf('Amplitude (TE-case, d=%.1d [m], \\lambda = %.2d [m])',d,lambda));xlim([theta_min theta_max]);xlabel('\Theta [deg]');ylabel(ylabel100);grid on;
subplot(212);plot(THETA_I_DEG,real(EPT),THETA_I_DEG,real(EPR));legend('E_t/E_0','E_r/E_0','location','northwest');title(sprintf('Amplitude (TM-case, d=%.1d [m], \\lambda = %.2d [m])',d,lambda));xlim([theta_min theta_max]);xlabel('\Theta [deg]');ylabel(ylabel100);grid on;

%==== INTENSITIES ====
RS = ((RSR).*conj(RSR));
RP = ((RPR).*conj(RPR));

COS_I = cos(THETA_I);
COS_T = cos(THETA_T_12);
f = n2/n0*(COS_T./COS_I);

TS = f.*((TSR).*conj(TSR));
TP = f.*((TPR).*conj(TPR));

%==== PLOT INTENSITIES ====

ylabel300 = 'I/I_0 [-]';

figure(300); hold off;
subplot(211);plot(THETA_I_DEG,TS,THETA_I_DEG,RS,THETA_I_DEG,TS+RS);legend('T(\theta)','R(\theta)','T(\theta)+R(\theta)','location','northwest');grid on;xlim([theta_min theta_max]);title(sprintf('Normalized Intensity TE-polarization (d=%.1d [m] = %.1d \\lambda)',d,nd));xlabel('\Theta [deg])');ylabel(ylabel300);
subplot(212);plot(THETA_I_DEG,TP,THETA_I_DEG,RP,THETA_I_DEG,TS+RS);legend('T(\theta)','R(\theta)','T(\theta)+R(\theta)','location','northwest');grid on;xlim([theta_min theta_max]);title(sprintf('Normalized Intensity TM-polarization (d=%.1d [m] = %.1d \\lambda)',d,nd));xlabel('\Theta [deg])');ylabel(ylabel300);

%==== FINESSE ====

% n0 = 1;
% 
% nmin = 1;
% nmax = 4;
% dn = 0.01;
% N1 = nmin:dn:nmax;
% 
% n2 = 1;
% 
% theta_deg = 0;
% theta_i = theta_deg*pi/180;
% 
% [TS01,TP01,RS01,RP01,THETA_T_01] = fresnel(n0,N1,theta_i);
% [TS10,TP10,RS10,RP10,THETA_T_10] = fresnel(N1,n0,THETA_T_01);
% [TS12,TP12,RS12,RP12,THETA_T_12] = fresnel(N1,n2,THETA_T_01);
% 
% TMP = ( 1 - RS10.*RS12 );
% FS = 4 * ( RS10.*RS12 ) ./ ( TMP .* TMP );
% 
% TMP = ( 1 - RP10.*RP12 );
% FP = 4 * ( RP10.*RP12 ) ./ ( TMP .* TMP );
% 
% clear TMP;
% 
% ylabel200 = 'Finesse [-]';
% 
% figure(200); hold off;
% subplot(211);plot(N1,FS);legend('F(\theta)','location','northwest');grid on;xlim([nmin nmax]);title(sprintf('Finesse over n_1, TE-polarization (d=%.1d [m] = %.1d \\lambda)',d,nd));xlabel('n_1 [-])');ylabel(ylabel200);
% subplot(212);plot(N1,FP);legend('F(\theta)','location','northwest');grid on;xlim([nmin nmax]);title(sprintf('Finesse over n_1, TM-polarization (d=%.1d [m] = %.1d \\lambda)',d,nd));xlabel('n_1 [-])');ylabel(ylabel200);

